# $Id: /mirror/youri/soft/submit/trunk/lib/Youri/Submit/Test/History.pm 1381 2006-12-02T10:47:18.983788Z guillomovitch  $
package Youri::Submit::Test::History;

=head1 NAME

Youri::Submit::Test::History - Non-linear history test

=head1 DESCRIPTION

This test plugin rejects packages whose history does not include last
available revision one.

=cut

use warnings;
use strict;
use Carp;
use Youri::Package;
use List::MoreUtils qw/none/;
use base qw/Youri::Submit::Test/;

sub process_package {
    my ($self, $package, $repository, $target, $define) = @_;
    croak "Not a class method" unless ref $self;

    my @errors;

    my $current_package =
        $repository->get_last_older_revision($package, $target, $define);

    # new package
    return unless $current_package;
    
    # skip the test if last revision has been produced from another
    # source package, as it occurs during package split/merges
    return 
        if $current_package->get_canonical_name()
        ne $package->get_canonical_name();

    my $last_change_author = 
        $current_package->get_last_change()->get_author();

    if (
        none { $last_change_author eq $_ }
        map { $_->get_author() }
        $package->get_changes()
    ) {
        push(
            @errors,
            "Last changelog entry $last_change_author from current package $current_package missing from changelog"
        );
    }

    return @errors;
}

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2002-2006, YOURI project

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

1;
