# $Id: /mirror/youri/soft/submit/trunk/lib/Youri/Submit/Test/Tag.pm 1381 2006-12-02T10:47:18.983788Z guillomovitch  $
package Youri::Submit::Test::Tag;

=head1 NAME

Youri::Submit::Test::Tag - Incorrect tag values test

=head1 DESCRIPTION

This test plugin rejects packages with incorrect tag values, based on regular
expressions.

=cut

use warnings;
use strict;
use Carp;
use base qw/Youri::Submit::Test/;

sub _init {
    my $self   = shift;
    my %options = (
        tags => undef, # expected tag values
        @_
    );

    croak "no tags to test" unless $options{tags};
    croak "tag should be an hashref" unless ref $options{tags} eq 'HASH';

    $self->{_tags} = $options{tags};
}

sub process_package {
    my ($self, $package, $repository, $target, $define) = @_;
    croak "Not a class method" unless ref $self;

    my @errors;

    foreach my $tag (keys %{$self->{_tags}}) {
        my $value = $package->get_tag($tag);
        if ($value !~ /$self->{_tags}->{$tag}/) {
            push(
                @errors,
                "invalid value $value for tag $tag"
            );
        }
    }

    return @errors;

}

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2002-2006, YOURI project

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

1;
